@@ -1,6 +1,6 @@
 use crate::appender::{FastLogRecord, LogAppender};
 use std::cell::RefCell;
-use std::fs::{File, OpenOptions, DirBuilder};
+use std::fs::{File, OpenOptions};
 use std::io::Write;
 
 /// only write append into file
@@ -35,6 +35,9 @@ impl LogAppender for FileAppender {
             buf.push(x);
         }
         log_file.write_all(buf.as_slice());
-        log_file.flush();
+    }
+
+    fn flush(&self) {
+        self.file.borrow_mut().flush();
     }
 }
